<?php
/**
 * Daisycon api http request
 *
 * @category  Daisycon
 * @package   Daisycon_Affiliatemarketing
 * @copyright Copyright (c) 2018 Daisycon B.V.
 * @author    Daisycon B.V. <support@daisycon.com>
 */
class Daisycon_Affiliatemarketing_Model_Api_Request extends Daisycon_Affiliatemarketing_Model_Api_Message
{
    const GET    = 'GET';
    const POST   = 'POST';
    const PUT    = 'PUT';
    const DELETE = 'DELETE';

    /**
     * Http request method
     *
     * @var string
     */
    protected $_method = self::GET;

    /**
     * Url of the request
     *
     * @var string
     */
    protected $_url;

    /**
     * Daisycon_Affiliatemarketing_Model_Api_Request constructor.
     *
     * @param string $method
     * @param string $url
     * @param array $headers
     * @param string $body
     */
    public function __construct($method, $url, array $headers = array(), $body = '')
    {
        $this->setMethod($method)
            ->setUrl($url)
            ->setHeaders($headers)
            ->setBody($body);
    }

    /**
     * Set the request method (get, put, post etc.)
     *
     * @param $method
     * @return $this
     */
    public function setMethod($method)
    {
        $this->_method = $method;
        return $this;
    }

    /**
     * Get the http method
     *
     * @return string
     */
    public function getMethod()
    {
        return $this->_method;
    }

    /**
     * Set the request url
     *
     * @param $url
     * @return $this
     */
    public function setUrl($url)
    {
        $this->_url = $url;
        return $this;
    }

    /**
     * Get the request url
     *
     * @return string
     */
    public function getUrl()
    {
        return $this->_url;
    }
}
