<?php
/**
 * Daisycon system login validator
 *
 * @category  Daisycon
 * @package   Daisycon_Affiliatemarketing
 * @copyright Copyright (c) 2018 Daisycon B.V.
 * @author    Daisycon B.V. <support@daisycon.com>
 */
class Daisycon_Affiliatemarketing_Model_System_Config_Validation_Login extends Mage_Core_Model_Config_Data
{
    /**
     * Override save
     *
     * Login to the api and retrieve the advertisers and programs, but don't save the credentials
     * 
     * @throws Mage_Core_Exception
     * @return $this
     */
    public function save()
    {
        $username = $this->getFieldsetDataValue('username');
        $password = $this->getValue();

        if (true === empty($password)) {
            return $this;
        }

        $helper = Mage::helper('affiliatemarketing');

        $result = $helper->loadAccountData($username, $password);

        if (true === empty($result)) {
            Mage::throwException($helper->__('Could not find any advertisers'));
        }

        $this->_getConfig()->setAdvertiserPrograms($result);

        $programIds = array();
        foreach ($result as $advertiser) {
            if (false === empty($advertiser['programs'])) {
                foreach ($advertiser['programs'] as $program) {
                    $programIds[] = $program['id'];
                }
            }
        }

        if (1 === count($programIds)) {
            Mage::register('affiliatemarketing_general_program_id', reset($programIds));
        }

        // Remove the password, don't save
        $this->setValue('');

        return parent::save();
    }

    /**
     * Get the daisycon affiliatemarketing config
     *
     * @return Daisycon_Affiliatemarketing_Model_Config
     */
    protected function _getConfig()
    {
        return Mage::getSingleton('affiliatemarketing/config');
    }
}
